@@ -29,4 +29,10 @@ sub update{
     $self;
 }
 
+sub send {
+    my $self = shift;
+    my $content = shift;
+    $self->{_client}->send_message($self,$content);
+}
+
 1;
