@@ -1,5 +1,7 @@
 package Mojo::Webqq::Plugin::Perldoc;
+$Mojo::Webqq::Plugin::Perldoc::PRIORITY = 96;
 use Pod::Perldoc;
+use Term::ANSIColor;
 use Mojo::Webqq::Run;
 use Mojo::Webqq::Cache;
 my $metacpan_module_api = 'http://api.metacpan.org/v0/module/';
@@ -8,11 +10,12 @@ my $metacpan_cache  = Mojo::Webqq::Cache->new;
 sub call{
     my $client = shift;
     my $data = shift;
-    $client->on(receive_message=>sub{
+    my $callback = sub{
         my($client,$msg)=@_;
         return if not $msg->allow_plugin;
         if($msg->content =~ /perldoc\s+-(v|f)\s+([^ ]+)/){
             $msg->allow_plugin(0);
+            return if $msg->msg_class eq "send" and $msg->msg_from ne "api" and $msg->msg_from ne "irc";
             my($p,$v) = ("-$1",$2);
             my $run = Mojo::Webqq::Run->new;
             $run->log($client->log);
@@ -36,13 +39,15 @@ sub call{
                         $reply .= "\n查看更多内容: http://perldoc.perl.org/index-functions.html" if $p eq "-f";
                         $reply .= "\n查看更多内容: http://perldoc.perl.org/perlvar.html" if $p eq "-v";
                     }
+                    eval{$reply = Term::ANSIColor::colorstrip($reply);};
                     $client->reply_message($msg,$reply) if $reply;
                 },
             );
             #$run->start;
         }
-        elsif($msg->content =~ /perldoc\s+((\w+::)*\w+)/){# or $msg->content =~ /((\w+::)+\w+)/){
+        elsif($msg->content =~ /perldoc\s+((\w+::)*\w+)/){
             $msg->allow_plugin(0);
+            return if $msg->msg_class eq "send" and $msg->msg_from ne "api" and $msg->msg_from ne "irc";
             my $module = $1;
             my $cache  = $metacpan_cache->retrieve($module);
             if(defined $cache){
@@ -88,6 +93,8 @@ sub call{
                 }
             }); 
         }
-    });
+    };
+    $client->on(receive_message=>$callback);
+    $client->on(send_message=>$callback);
 }
 1;
